@@ -29,7 +29,9 @@ class Subscriptions(PersistentMapping):
         return filter(lambda o: o is not None, [mtool.getMemberById(sid) for sid in subscriberids])
 
     def add(self, obj, user):
-        """ Adds user """
+        """
+        Adds user
+        """
         obj_id = self.key_for_obj(obj)
         if obj_id not in self.keys():
             self[obj_id] = PersistentList()
@@ -38,19 +40,25 @@ class Subscriptions(PersistentMapping):
             self[obj_id].append(user)
 
     def check_subscriber(self, obj):
-        """ Checks user """
+        """
+        Checks user
+        """
         mtool = getToolByName(obj, 'portal_membership')
         user = mtool.getAuthenticatedMember().getId()
         return self.check_subscriber_id(self.key_for_obj(obj), user)
 
     def check_subscriber_id(self, obj_id, user):
-        """ Checks user """
+        """
+        Checks user
+        """
         if obj_id not in self.keys():
             return False
         return user in self[obj_id]
 
     def remove(self, obj, user):
-        """ Deletes user """
+        """
+        Deletes user
+        """
         obj_id = self.key_for_obj(obj)
         if self.check_subscriber_id(obj_id, user):
             log.info('Removing subscription of user %s to %s' % (user, obj_id))
@@ -58,3 +66,12 @@ class Subscriptions(PersistentMapping):
             if len(self[obj_id]) == 0:
                 del self[obj_id]
 
+    def move_subscribers(self, object_moved_event):
+        """
+        a thread is being moved from one forum to another - 
+        move subscriptions also.
+        """
+        old_key = '{forum}/{thread}'.format(forum='/'.join(object_moved_event.oldParent.getPhysicalPath()), thread=object_moved_event.oldName)
+        new_key = self.key_for_obj(object_moved_event.object)
+        self[new_key] = self[old_key]
+        del self[old_key]
