@@ -3,6 +3,7 @@ import transaction
 from Testing import ZopeTestCase
 from zope.component import getGlobalSiteManager
 from zope.interface.verify import verifyObject
+from zope.lifecycleevent import ObjectMovedEvent
 from Products.CMFCore.interfaces import ISiteRoot
 from mocks import MembershipToolMock, ForumMock, ConversationMock, MemberDataMock
 from hl.plone.boardnotifications.interfaces import ISubscriptions
@@ -51,6 +52,24 @@ class SubscriptionTests(unittest.TestCase):
         email = got[0].getProperty('email')
         self.failUnless(email == 'max.mustermann@haufe-lexware.com', 'wrong memberdata %s' % got[0])
 
+    def test_move_subscriptions(self):
+        subscriptions = self._make_one()
+        forum = ForumMock('anotherforum', 'awesome test forum')
+        thread = self.app.testforum.testthread
+        self.app._setObject(forum.id, forum)
+        subscriptions.add(thread, '123456')
+        self.app.anotherforum._setObject(thread.id, thread)
+        thread.forum = forum
+        ev = ObjectMovedEvent(thread, self.app.testforum, thread.id, self.app.anotherforum, thread.id)
+        subscriptions.move_subscribers(ev)
+        expected = 'anotherforum/testthread'
+        got = subscriptions.key_for_obj(self.app.anotherforum.testthread)
+        self.failUnless(expected == got, 'unexpected object key: {got}'.format(got=got))
+        got = subscriptions.subscribers_for(thread)
+        self.failUnless(len(got) == 1, 'expected one subscriber')
+        email = got[0].getProperty('email')
+        self.failUnless(email == 'max.mustermann@haufe-lexware.com', 'wrong memberdata %s' % got[0])
+
 
 def test_suite():
     return unittest.TestSuite((
